# pynth

[![PyPI - Version](https://img.shields.io/pypi/v/pynth.svg)](https://pypi.org/project/pynth)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pynth.svg)](https://pypi.org/project/pynth)

---

[Demo](demo.ipynb)

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install pynth
```

## License

`pynth` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
